@@ -86,7 +86,7 @@ Q_GLOBAL_STATIC(CGroupSystemInformation, s_cGroupSystemInformation)
 // - app[-<launcher>]-<ApplicationID>-<RANDOM>.scope
 // - app[-<launcher>]-<ApplicationID>[@<RANDOM>].service
 // Flatpak's are currently in a cgroup, but they don't follow the specification
-// this has been fixed, but this provides some compatability till that lands
+// this has been fixed, but this provides some compatibility till that lands
 // app vs apps exists because the spec changed.
 QRegularExpression
     CGroupPrivate::s_appIdFromProcessGroupPattern(QStringLiteral("(apps|app|flatpak)-(?:[^-]*-)?([^-]+(?=-.*\\.scope)|[^@]+(?=(?:@.*)?\\.service))"));
@@ -136,7 +136,11 @@ QString CGroupPrivate::unescapeName(const QString &name)
         if (escapeCharIndex < 0) {
             break;
         }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QStringRef sequence = rc.midRef(escapeCharIndex, 4);
+#else
+        const QStringView sequence = rc.mid(escapeCharIndex, 4);
+#endif
         if (sequence.length() != 4 || sequence.at(1) != QLatin1Char('x')) {
             qWarning() << "Badly formed cgroup name" << name;
             return name;
