@@ -4,11 +4,9 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "extended_process_list.h"
-#include "kcoreaddons_version.h"
 
 #include <KLocalizedString>
 #include <KPluginFactory>
-#include <KPluginLoader>
 #include <KPluginMetaData>
 #include <KUser>
 
@@ -53,7 +51,7 @@ public:
                 if (!process->changes().testFlag(m_changeFlag)) {
                     return;
                 }
-                emit dataChanged(process);
+                Q_EMIT dataChanged(process);
             });
         }
     }
@@ -63,6 +61,19 @@ public:
         return QVariant::fromValue(m_extractFunc(process));
     }
 
+    QVariant cgroupData(KSysGuard::CGroup *cgroup, const QVector<KSysGuard::Process *> &groupProcesses) const override
+    {
+        switch (m_groupPolicy) {
+        case Accumulate:
+            return ProcessAttribute::cgroupData(cgroup, groupProcesses);
+        case Average:
+            return ProcessAttribute::cgroupData(cgroup, groupProcesses).toDouble() / groupProcesses.size();
+        case ForwardFirstEntry:
+            return groupProcesses.isEmpty() ? QVariant() : data(groupProcesses.first());
+        }
+        Q_UNREACHABLE();
+    }
+
 private:
     std::function<T(KSysGuard::Process *)> m_extractFunc;
     KSysGuard::Process::Change m_changeFlag;
@@ -540,11 +551,7 @@ QVector<ProcessAttribute *> ExtendedProcesses::extendedAttributes() const
 
 void ExtendedProcesses::Private::loadPlugins()
 {
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(5, 86, 0)
-    const QVector<KPluginMetaData> listMetaData = KPluginLoader::findPlugins(QStringLiteral("ksysguard/process"));
-#else
     const QVector<KPluginMetaData> listMetaData = KPluginMetaData::findPlugins(QStringLiteral("ksysguard/process"));
-#endif
     // instantiate all plugins
     for (const auto &pluginMetaData : listMetaData) {
         qCDebug(LIBKSYSGUARD_PROCESSCORE) << "loading plugin" << pluginMetaData.name();
